From 2b5c60f130bf5d6e0ad4521d327b81947cd2eab7 Mon Sep 17 00:00:00 2001
From: ulrich
Date: Mon, 05 Apr 2021 13:42:39 +0000
Subject: [PATCH] Alle Faelle (Liste, Neu, Lesen, Aendern, Loeschen) fuer Ablageort fertig
---
src/de/uhilger/mediaz/store/FileStorage.java | 111 +++++++++++++++++++++++++++++++++++++------------------
1 files changed, 74 insertions(+), 37 deletions(-)
diff --git a/src/de/uhilger/mediaz/store/FileStorage.java b/src/de/uhilger/mediaz/store/FileStorage.java
index 1d6373a..90a99a1 100644
--- a/src/de/uhilger/mediaz/store/FileStorage.java
+++ b/src/de/uhilger/mediaz/store/FileStorage.java
@@ -1,11 +1,24 @@
/*
- * To change this license header, choose License Headers in Project Properties.
- * To change this template file, choose Tools | Templates
- * and open the template in the editor.
+ Mediazentrale - Personal Media Center
+ Copyright (C) 2021 Ulrich Hilger
+
+ This program is free software: you can redistribute it and/or modify
+ it under the terms of the GNU Affero General Public License as
+ published by the Free Software Foundation, either version 3 of the
+ License, or (at your option) any later version.
+
+ This program is distributed in the hope that it will be useful,
+ but WITHOUT ANY WARRANTY; without even the implied warranty of
+ MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ GNU Affero General Public License for more details.
+
+ You should have received a copy of the GNU Affero General Public License
+ along with this program. If not, see <https://www.gnu.org/licenses/>.
*/
package de.uhilger.mediaz.store;
import com.google.gson.Gson;
+import com.google.gson.reflect.TypeToken;
import de.uhilger.mediaz.App;
import de.uhilger.mediaz.Server;
import de.uhilger.mediaz.entity.Ablageort;
@@ -18,11 +31,13 @@
import java.util.logging.Logger;
import de.uhilger.mediaz.entity.Entity;
import java.util.ArrayList;
+import java.util.HashMap;
import java.util.List;
+import java.util.Map;
import java.util.logging.Level;
/**
* Ablage fuer Dateien
*
* [Basispfad]/[Typ]/[Name]
*
@@ -41,8 +56,15 @@
private String fileBase;
+ private Map<String, TypeToken> types;
+
public FileStorage(String base) {
this.fileBase = base;
+
+ // Beispiel: TypeToken<List<String>> list = new TypeToken<List<String>>() {};
+ TypeToken<Ablageort> ttAblageort = new TypeToken<Ablageort>() {};
+ types = new HashMap();
+ types.put(Ablageort.class.getSimpleName(), ttAblageort);
}
/**
@@ -56,58 +78,45 @@
* Der Name der Ablage muss eindeutig sein
*
*
- * @param o
+ * @param entity
*/
- public File writeToFile(Entity o) throws IOException {
- Gson gson = new Gson();
- String className = o.getClass().getSimpleName();
+ public File writeToFile(Entity entity) throws IOException {
+ String className = entity.getClass().getSimpleName();
logger.finer(className);
File dir = new File(fileBase, className);
dir.mkdirs();
- File file = new File(dir, o.getName());
+ File file = new File(dir, entity.getName());
if(file.exists()) {
file.delete();
}
FileWriter fw = new FileWriter(file);
- fw.write(gson.toJson(o));
+ Gson gson = new Gson();
+ fw.write(gson.toJson(entity));
fw.flush();
fw.close();
return file;
}
- public Entity readFromFile(File file) throws ClassNotFoundException, FileNotFoundException, IOException {
- String type = typeFromName(file);
+ public String readFromFile(File file) throws IOException {
StringBuilder sb = new StringBuilder();
- FileReader in = new FileReader(file);
- BufferedReader r = new BufferedReader(in);
+ BufferedReader r = new BufferedReader(new FileReader(file));
String line = r.readLine();
while(line != null) {
sb.append(line);
line = r.readLine();
}
r.close();
- in.close();
- String json = sb.toString();
- Gson gson = new Gson();
- switch(type) {
- case ST_ABLAGEORT:
- return gson.fromJson(json, Ablageort.class);
- default:
- Ablageort ablage = new Ablageort();
- ablage.setName("Test");
- return ablage;
- }
+ return sb.toString();
}
- private String typeFromName(File file) {
- //String path = file.getPath();
- //logger.info(path);
+ public Entity entityFromFile(File file) throws ClassNotFoundException, FileNotFoundException, IOException {
+ String json = readFromFile(file);
+ Gson gson = new Gson();
+ return gson.fromJson(json, typeFromName(typeNameFromPath(file)).getType());
+ }
+
+ private String typeNameFromPath(File file) {
String[] parts = file.getPath().split(App.getRs(Server.RB_SLASH));
- //for(String part : parts) {
- //logger.info(part);
- //}
- //logger.info("" + parts.length);
- logger.info(parts[parts.length-2]);
return parts[parts.length-2];
}
@@ -123,11 +132,8 @@
@Override
public Entity read(String typ, String name) {
- File base = new File(fileBase);
- File dir = new File(base, typ);
- File file = new File(dir, name);
try {
- return readFromFile(file);
+ return entityFromFile(getFile(typ, name));
} catch (ClassNotFoundException | IOException ex) {
logger.log(Level.SEVERE, null, ex);
return null;
@@ -146,6 +152,37 @@
return list;
}
+ @Override
+ public TypeToken typeFromName(String name) {
+ return types.get(name);
+ }
+
+ @Override
+ public String readJson(String typ, String name) {
+ try {
+ return readFromFile(getFile(typ, name));
+ } catch (IOException ex) {
+ logger.log(Level.SEVERE, null, ex);
+ return null;
+ }
+ }
+
+ private File getFile(String typ, String name) {
+ File base = new File(fileBase);
+ File dir = new File(base, typ);
+ return new File(dir, name);
+ }
+
+ @Override
+ public boolean delete(String typ, String name) {
+ File file = getFile(typ, name);
+ if(file.exists()) {
+ return file.delete();
+ } else {
+ return false;
+ }
+ }
+
}
@@ -18,11 +31,13 @@
import java.util.logging.Level;
/**
- * Ablage fuer Dateien
+ * Ablage fuer Dateien der Mediazentrale
*
* [Basispfad]/[Typ]/[Name]
--
Gitblit v1.9.3